@@ -1,7 +1,7 @@
 import numpy as np
+import os
 
 import gensim
-from gensim import downloader
 import spacy
 import torch
 import transformers as ppb
@@ -39,9 +39,14 @@ class Vectorizer:
         self.vectors = vectors
         return vectors
 
-    def w2v(self, words, pretrained_model='glove-wiki-gigaword-300', ensemble_method='mean'):
+    def w2v(self, words, **kwargs):
         self.words = words
-        model = gensim.downloader.load(pretrained_model)
+        model_path_default = os.path.join(os.path.abspath(os.getcwd()), 'glove-wiki-gigaword-300')
+
+        model_path = kwargs.get('model_path', model_path_default)
+        ensemble_method = kwargs.get('ensemble_method', 'mean')
+
+        model = gensim.models.KeyedVectors.load_word2vec_format(model_path)
 
         vectors = []
         for element in words:
